@@ -5,11 +5,7 @@
 #' function allows you to see these messages printed in the R console directly
 #' rather than having to open the JavaScript console in the browser to view the
 #' messages.\cr\cr
-#' This function must be called in a Shiny app's server function, and you also
-#' need to pass the \code{showLog=TRUE} parameter to \code{useShinyjs()}.
-#' @note Due to an issue in shiny (see
-#' https://github.com/rstudio/shiny/issues/928), duplicated consecutive log
-#' messages will not get printed in R.
+#' This function must be called in a Shiny app's server.
 #' @note Log messages that cannot be serialized in JavaScript (such as many
 #' JavaScript Event objects that are cyclic) will not be printed in R.
 #' @examples
@@ -23,13 +19,14 @@
 #'     ),
 #'     server = function(input, output) {
 #'       showLog()
+#'       logjs("App started")
 #'       observe({
 #'         logjs(paste("Length of text:", nchar(input$text)))
 #'       })
 #'     }
 #'   )
 #' }
-#' @seealso \code{\link[shinyjs]{logjs}}
+#' @seealso [logjs()]
 #' @export
 showLog <- function() {
   session <- getSession()
@@ -53,10 +50,10 @@ showLog <- function() {
         };
       })();'
     )))
-  })
+  }, immediate = TRUE)
 
   shiny::observeEvent(session$input[['shinyjs-showLog']], {
-    message("JAVASCRIPT LOG: ",
+    message("[JAVASCRIPT LOG] ",
             jsonlite::toJSON(session$input[['shinyjs-showLog']],
                              auto_unbox = TRUE)
     )
